==> joinfaces-autoconfigure-4.7.14-sources.jar: org/joinfaces/autoconfigure/servlet/initparams/ServletContextInitParameterPropertiesAutoConfiguration.java <==
/*
 * Copyright 2016-2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.joinfaces.autoconfigure.servlet.initparams;

import java.util.List;

import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.ServletContextInitializer;
import org.springframework.context.annotation.Bean;

/**
 * Common base class for all auto-configuration classes which provide properties
 * as {@link javax.servlet.ServletContext} init parameters.
 *
 * @author Lars Grefer
 */
@AutoConfiguration
@ConditionalOnWebApplication
public class ServletContextInitParameterPropertiesAutoConfiguration {

	@Bean
	@ConditionalOnBean(ServletContextInitParameterProperties.class)
	public ServletContextInitializer servletContextInitParameterInitializer(List<ServletContextInitParameterProperties> initParameterProperties) {
		return new InitParameterServletContextConfigurer(initParameterProperties);
	}
}

==> joinfaces-autoconfigure-5.2.2-sources.jar: org/joinfaces/autoconfigure/servlet/initparams/ServletContextInitParameterPropertiesAutoConfiguration.java <==
/*
 * Copyright 2016-2022 the original author or authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.joinfaces.autoconfigure.servlet.initparams;

import java.util.List;

import org.springframework.boot.autoconfigure.AutoConfiguration;
import org.springframework.boot.autoconfigure.condition.ConditionalOnBean;
import org.springframework.boot.autoconfigure.condition.ConditionalOnWebApplication;
import org.springframework.boot.web.servlet.ServletContextInitializer;
import org.springframework.context.annotation.Bean;

/**
 * Common base class for all auto-configuration classes which provide properties
 * as {@link jakarta.servlet.ServletContext} init parameters.
 *
 * @author Lars Grefer
 */
@AutoConfiguration
@ConditionalOnWebApplication
public class ServletContextInitParameterPropertiesAutoConfiguration {

	@Bean
	@ConditionalOnBean(ServletContextInitParameterProperties.class)
	public ServletContextInitializer servletContextInitParameterInitializer(List<ServletContextInitParameterProperties> initParameterProperties) {
		return new InitParameterServletContextConfigurer(initParameterProperties);
	}
}
